@@ -298,7 +298,7 @@ int gpiod_simple_event_loop(const char *consumer, const char *device,
 		status = gpiod_line_event_wait(line, timeout);
 		if (status < 0) {
 			if (gpiod_errno() == EINTR)
-				return evtype = GPIOD_EVENT_CB_TIMEOUT;
+				evtype = GPIOD_EVENT_CB_TIMEOUT;
 			else
 				goto out;
 		} else if (status == 0) {
@@ -1071,6 +1071,8 @@ struct gpiod_chip * gpiod_chip_open_by_label(const char *label)
 		}
 	}
 
+	set_last_error(ENOENT);
+
 out:
 	gpiod_chip_iter_free(iter);
 	return  NULL;
